@@ -145,13 +145,13 @@ enum : int {
     SBK_QtQml_IDX_COUNT                                      = 45
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtQmlTypes;
+extern PyTypeObject **SbkPySide2_QtQmlTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtQmlModuleObject;
+extern PyObject *SbkPySide2_QtQmlModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtQmlTypeConverters;
+extern SbkConverter **SbkPySide2_QtQmlTypeConverters;
 
 // Converter indices
 enum : int {
@@ -159,10 +159,10 @@ enum : int {
     SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 1, // QList<QByteArray >
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 2, // const QList<QJSValue > &
     SBK_QTQML_QLIST_QQMLERROR_IDX                            = 3, // QList<QQmlError > *
-    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 4, // const QHash<QString,QVariant > &
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 5, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 6, // QList<QString >
-    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 7, // QMap<QString,QVariant >
+    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 4, // const QMap<QString,QVariant > &
+    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 5, // const QHash<QString,QVariant > &
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 7, // QList<QString >
     SBK_QtQml_CONVERTERS_IDX_COUNT                           = 8
 };
 // Macros for type check
@@ -171,49 +171,52 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QJSEngine::Extension >() { return SbkPySide2_QtQmlTypes[SBK_QJSENGINE_EXTENSION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QJSEngine::Extension> >() { return SbkPySide2_QtQmlTypes[SBK_QFLAGS_QJSENGINE_EXTENSION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QJSEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QJSENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QJSValue::SpecialValue >() { return SbkPySide2_QtQmlTypes[SBK_QJSVALUE_SPECIALVALUE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QJSValue::ErrorType >() { return SbkPySide2_QtQmlTypes[SBK_QJSVALUE_ERRORTYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QJSValue >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QJSVALUE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QJSValueIterator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QJSVALUEITERATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlAbstractUrlInterceptor::DataType >() { return SbkPySide2_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlAbstractUrlInterceptor >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlApplicationEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLAPPLICATIONENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlComponent::CompilationMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlComponent::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_STATUS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlComponent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlContext >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLCONTEXT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlDebuggingEnabler::StartMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlDebuggingEnabler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlEngine::ObjectOwnership >() { return SbkPySide2_QtQmlTypes[SBK_QQMLENGINE_OBJECTOWNERSHIP_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlError >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLERROR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlExpression >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLEXPRESSION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlExtensionInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLEXTENSIONINTERFACE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlExtensionPlugin >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLEXTENSIONPLUGIN_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlFile::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLFILE_STATUS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlFile >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLFILE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlFileSelector >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLFILESELECTOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlImageProviderBase::ImageType >() { return SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlImageProviderBase::Flag >() { return SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QQmlImageProviderBase::Flag> >() { return SbkPySide2_QtQmlTypes[SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlImageProviderBase >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlIncubationController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATIONCONTROLLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlIncubator::IncubationMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlIncubator::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_STATUS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlIncubator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlListReference >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLLISTREFERENCE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlNetworkAccessManagerFactory >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlParserStatus >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLPARSERSTATUS_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlProperty::PropertyTypeCategory >() { return SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlProperty::Type >() { return SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_TYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQmlProperty >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlPropertyMap >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTYMAP_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlPropertyValueSource >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTYVALUESOURCE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlScriptString >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLSCRIPTSTRING_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QQmlTypesExtensionInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQmlTypes[SBK_QQMLTYPESEXTENSIONINTERFACE_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QJSEngine::Extension >() { return SbkPySide2_QtQmlTypes[SBK_QJSENGINE_EXTENSION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QJSEngine::Extension> >() { return SbkPySide2_QtQmlTypes[SBK_QFLAGS_QJSENGINE_EXTENSION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QJSENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSValue::SpecialValue >() { return SbkPySide2_QtQmlTypes[SBK_QJSVALUE_SPECIALVALUE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSValue::ErrorType >() { return SbkPySide2_QtQmlTypes[SBK_QJSVALUE_ERRORTYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QJSVALUE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSValueIterator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QJSVALUEITERATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor::DataType >() { return SbkPySide2_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlApplicationEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLAPPLICATIONENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlComponent::CompilationMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlComponent::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_STATUS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlComponent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLCOMPONENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlContext >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLCONTEXT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler::StartMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlEngine::ObjectOwnership >() { return SbkPySide2_QtQmlTypes[SBK_QQMLENGINE_OBJECTOWNERSHIP_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlError >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLERROR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlExpression >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLEXPRESSION_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlExtensionInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLEXTENSIONINTERFACE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlExtensionPlugin >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLEXTENSIONPLUGIN_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlFile::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLFILE_STATUS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlFile >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLFILE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlFileSelector >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLFILESELECTOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlImageProviderBase::ImageType >() { return SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlImageProviderBase::Flag >() { return SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QQmlImageProviderBase::Flag> >() { return SbkPySide2_QtQmlTypes[SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlImageProviderBase >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLIMAGEPROVIDERBASE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlIncubationController >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATIONCONTROLLER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlIncubator::IncubationMode >() { return SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlIncubator::Status >() { return SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_STATUS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlIncubator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLINCUBATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlListReference >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLLISTREFERENCE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlNetworkAccessManagerFactory >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlParserStatus >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLPARSERSTATUS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlProperty::PropertyTypeCategory >() { return SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlProperty::Type >() { return SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQmlProperty >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlPropertyMap >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTYMAP_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlPropertyValueSource >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTYVALUESOURCE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlScriptString >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLSCRIPTSTRING_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlTypesExtensionInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLTYPESEXTENSIONINTERFACE_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
