@@ -83,13 +83,13 @@ enum : int {
     SBK_QtSvg_IDX_COUNT                                      = 4
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtSvgTypes;
+extern PyTypeObject **SbkPySide2_QtSvgTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtSvgModuleObject;
+extern PyObject *SbkPySide2_QtSvgModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtSvgTypeConverters;
+extern SbkConverter **SbkPySide2_QtSvgTypeConverters;
 
 // Converter indices
 enum : int {
@@ -109,10 +109,13 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSvgGenerator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGGENERATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSvgRenderer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGRENDERER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGWIDGET_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSvgGenerator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGGENERATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSvgRenderer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGRENDERER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGWIDGET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
