@@ -98,9 +98,12 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QX11Info::PeekOption >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_PEEKOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QX11Info::PeekOption> >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QFLAGS_QX11INFO_PEEKOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QX11Info >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
